@@ -47,17 +47,19 @@
    * ssh-rsa *
    *********** */
 
-static int libssh2_hostkey_method_ssh_rsa_dtor(LIBSSH2_SESSION * session,
-                                               void **abstract);
+static int hostkey_method_ssh_rsa_dtor(LIBSSH2_SESSION * session,
+                                       void **abstract);
 
-/* {{{ libssh2_hostkey_method_ssh_rsa_init
+/*
+ * hostkey_method_ssh_rsa_init
+ *
  * Initialize the server hostkey working area with e/n pair
  */
 static int
-libssh2_hostkey_method_ssh_rsa_init(LIBSSH2_SESSION * session,
-                                    const unsigned char *hostkey_data,
-                                    unsigned long hostkey_data_len,
-                                    void **abstract)
+hostkey_method_ssh_rsa_init(LIBSSH2_SESSION * session,
+                            const unsigned char *hostkey_data,
+                            unsigned long hostkey_data_len,
+                            void **abstract)
 {
     libssh2_rsa_ctx *rsactx;
     const unsigned char *s, *e, *n;
@@ -66,12 +68,12 @@ libssh2_hostkey_method_ssh_rsa_init(LIBSSH2_SESSION * session,
     (void) hostkey_data_len;
 
     if (*abstract) {
-        libssh2_hostkey_method_ssh_rsa_dtor(session, abstract);
+        hostkey_method_ssh_rsa_dtor(session, abstract);
         *abstract = NULL;
     }
 
     s = hostkey_data;
-    len = libssh2_ntohu32(s);
+    len = _libssh2_ntohu32(s);
     s += 4;
 
     if (len != 7 || strncmp((char *) s, "ssh-rsa", 7) != 0) {
@@ -79,12 +81,12 @@ libssh2_hostkey_method_ssh_rsa_init(LIBSSH2_SESSION * session,
     }
     s += 7;
 
-    e_len = libssh2_ntohu32(s);
+    e_len = _libssh2_ntohu32(s);
     s += 4;
 
     e = s;
     s += e_len;
-    n_len = libssh2_ntohu32(s);
+    n_len = _libssh2_ntohu32(s);
     s += 4;
     n = s;
     s += n_len;
@@ -98,23 +100,23 @@ libssh2_hostkey_method_ssh_rsa_init(LIBSSH2_SESSION * session,
     return 0;
 }
 
-/* }}} */
-
-/* {{{ libssh2_hostkey_method_ssh_rsa_initPEM
+/*
+ * hostkey_method_ssh_rsa_initPEM
+ *
  * Load a Private Key from a PEM file
  */
 static int
-libssh2_hostkey_method_ssh_rsa_initPEM(LIBSSH2_SESSION * session,
-                                       const char *privkeyfile,
-                                       unsigned const char *passphrase,
-                                       void **abstract)
+hostkey_method_ssh_rsa_initPEM(LIBSSH2_SESSION * session,
+                               const char *privkeyfile,
+                               unsigned const char *passphrase,
+                               void **abstract)
 {
     libssh2_rsa_ctx *rsactx;
     FILE *fp;
     int ret;
 
     if (*abstract) {
-        libssh2_hostkey_method_ssh_rsa_dtor(session, abstract);
+        hostkey_method_ssh_rsa_dtor(session, abstract);
         *abstract = NULL;
     }
 
@@ -134,17 +136,17 @@ libssh2_hostkey_method_ssh_rsa_initPEM(LIBSSH2_SESSION * session,
     return 0;
 }
 
-/* }}} */
-
-/* {{{ libssh2_hostkey_method_ssh_rsa_sign
+/*
+ * hostkey_method_ssh_rsa_sign
+ *
  * Verify signature created by remote
  */
 static int
-libssh2_hostkey_method_ssh_rsa_sig_verify(LIBSSH2_SESSION * session,
-                                          const unsigned char *sig,
-                                          unsigned long sig_len,
-                                          const unsigned char *m,
-                                          unsigned long m_len, void **abstract)
+hostkey_method_ssh_rsa_sig_verify(LIBSSH2_SESSION * session,
+                                  const unsigned char *sig,
+                                  unsigned long sig_len,
+                                  const unsigned char *m,
+                                  unsigned long m_len, void **abstract)
 {
     libssh2_rsa_ctx *rsactx = (libssh2_rsa_ctx *) (*abstract);
     (void) session;
@@ -155,18 +157,18 @@ libssh2_hostkey_method_ssh_rsa_sig_verify(LIBSSH2_SESSION * session,
     return _libssh2_rsa_sha1_verify(rsactx, sig, sig_len, m, m_len);
 }
 
-/* }}} */
-
-/* {{{ libssh2_hostkey_method_ssh_rsa_signv
+/*
+ * hostkey_method_ssh_rsa_signv
+ *
  * Construct a signature from an array of vectors
  */
 static int
-libssh2_hostkey_method_ssh_rsa_signv(LIBSSH2_SESSION * session,
-                                     unsigned char **signature,
-                                     unsigned long *signature_len,
-                                     unsigned long veccount,
-                                     const struct iovec datavec[],
-                                     void **abstract)
+hostkey_method_ssh_rsa_signv(LIBSSH2_SESSION * session,
+                             unsigned char **signature,
+                             unsigned long *signature_len,
+                             unsigned long veccount,
+                             const struct iovec datavec[],
+                             void **abstract)
 {
     libssh2_rsa_ctx *rsactx = (libssh2_rsa_ctx *) (*abstract);
     int ret;
@@ -189,13 +191,13 @@ libssh2_hostkey_method_ssh_rsa_signv(LIBSSH2_SESSION * session,
     return 0;
 }
 
-/* }}} */
-
-/* {{{ libssh2_hostkey_method_ssh_rsa_dtor
+/*
+ * hostkey_method_ssh_rsa_dtor
+ *
  * Shutdown the hostkey
  */
 static int
-libssh2_hostkey_method_ssh_rsa_dtor(LIBSSH2_SESSION * session, void **abstract)
+hostkey_method_ssh_rsa_dtor(LIBSSH2_SESSION * session, void **abstract)
 {
     libssh2_rsa_ctx *rsactx = (libssh2_rsa_ctx *) (*abstract);
     (void) session;
@@ -207,17 +209,15 @@ libssh2_hostkey_method_ssh_rsa_dtor(LIBSSH2_SESSION * session, void **abstract)
     return 0;
 }
 
-/* }}} */
-
-static const LIBSSH2_HOSTKEY_METHOD libssh2_hostkey_method_ssh_rsa = {
+static const LIBSSH2_HOSTKEY_METHOD hostkey_method_ssh_rsa = {
     "ssh-rsa",
     MD5_DIGEST_LENGTH,
-    libssh2_hostkey_method_ssh_rsa_init,
-    libssh2_hostkey_method_ssh_rsa_initPEM,
-    libssh2_hostkey_method_ssh_rsa_sig_verify,
-    libssh2_hostkey_method_ssh_rsa_signv,
+    hostkey_method_ssh_rsa_init,
+    hostkey_method_ssh_rsa_initPEM,
+    hostkey_method_ssh_rsa_sig_verify,
+    hostkey_method_ssh_rsa_signv,
     NULL,                       /* encrypt */
-    libssh2_hostkey_method_ssh_rsa_dtor,
+    hostkey_method_ssh_rsa_dtor,
 };
 #endif /* LIBSSH2_RSA */
 
@@ -226,17 +226,19 @@ static const LIBSSH2_HOSTKEY_METHOD libssh2_hostkey_method_ssh_rsa = {
    * ssh-dss *
    *********** */
 
-static int libssh2_hostkey_method_ssh_dss_dtor(LIBSSH2_SESSION * session,
-                                               void **abstract);
+static int hostkey_method_ssh_dss_dtor(LIBSSH2_SESSION * session,
+                                       void **abstract);
 
-/* {{{ libssh2_hostkey_method_ssh_dss_init
+/*
+ * hostkey_method_ssh_dss_init
+ *
  * Initialize the server hostkey working area with p/q/g/y set
  */
 static int
-libssh2_hostkey_method_ssh_dss_init(LIBSSH2_SESSION * session,
-                                    const unsigned char *hostkey_data,
-                                    unsigned long hostkey_data_len,
-                                    void **abstract)
+hostkey_method_ssh_dss_init(LIBSSH2_SESSION * session,
+                            const unsigned char *hostkey_data,
+                            unsigned long hostkey_data_len,
+                            void **abstract)
 {
     libssh2_dsa_ctx *dsactx;
     const unsigned char *p, *q, *g, *y, *s;
@@ -244,31 +246,31 @@ libssh2_hostkey_method_ssh_dss_init(LIBSSH2_SESSION * session,
     (void) hostkey_data_len;
 
     if (*abstract) {
-        libssh2_hostkey_method_ssh_dss_dtor(session, abstract);
+        hostkey_method_ssh_dss_dtor(session, abstract);
         *abstract = NULL;
     }
 
     s = hostkey_data;
-    len = libssh2_ntohu32(s);
+    len = _libssh2_ntohu32(s);
     s += 4;
     if (len != 7 || strncmp((char *) s, "ssh-dss", 7) != 0) {
         return -1;
     }
     s += 7;
 
-    p_len = libssh2_ntohu32(s);
+    p_len = _libssh2_ntohu32(s);
     s += 4;
     p = s;
     s += p_len;
-    q_len = libssh2_ntohu32(s);
+    q_len = _libssh2_ntohu32(s);
     s += 4;
     q = s;
     s += q_len;
-    g_len = libssh2_ntohu32(s);
+    g_len = _libssh2_ntohu32(s);
     s += 4;
     g = s;
     s += g_len;
-    y_len = libssh2_ntohu32(s);
+    y_len = _libssh2_ntohu32(s);
     s += 4;
     y = s;
     s += y_len;
@@ -280,23 +282,23 @@ libssh2_hostkey_method_ssh_dss_init(LIBSSH2_SESSION * session,
     return 0;
 }
 
-/* }}} */
-
-/* {{{ libssh2_hostkey_method_ssh_dss_initPEM
+/*
+ * hostkey_method_ssh_dss_initPEM
+ *
  * Load a Private Key from a PEM file
  */
 static int
-libssh2_hostkey_method_ssh_dss_initPEM(LIBSSH2_SESSION * session,
-                                       const char *privkeyfile,
-                                       unsigned const char *passphrase,
-                                       void **abstract)
+hostkey_method_ssh_dss_initPEM(LIBSSH2_SESSION * session,
+                               const char *privkeyfile,
+                               unsigned const char *passphrase,
+                               void **abstract)
 {
     libssh2_dsa_ctx *dsactx;
     FILE *fp;
     int ret;
 
     if (*abstract) {
-        libssh2_hostkey_method_ssh_dss_dtor(session, abstract);
+        hostkey_method_ssh_dss_dtor(session, abstract);
         *abstract = NULL;
     }
 
@@ -316,17 +318,17 @@ libssh2_hostkey_method_ssh_dss_initPEM(LIBSSH2_SESSION * session,
     return 0;
 }
 
-/* }}} */
-
-/* {{{ libssh2_hostkey_method_ssh_dss_sign
+/*
+ * libssh2_hostkey_method_ssh_dss_sign
+ *
  * Verify signature created by remote
  */
 static int
-libssh2_hostkey_method_ssh_dss_sig_verify(LIBSSH2_SESSION * session,
-                                          const unsigned char *sig,
-                                          unsigned long sig_len,
-                                          const unsigned char *m,
-                                          unsigned long m_len, void **abstract)
+hostkey_method_ssh_dss_sig_verify(LIBSSH2_SESSION * session,
+                                  const unsigned char *sig,
+                                  unsigned long sig_len,
+                                  const unsigned char *m,
+                                  unsigned long m_len, void **abstract)
 {
     libssh2_dsa_ctx *dsactx = (libssh2_dsa_ctx *) (*abstract);
 
@@ -341,18 +343,18 @@ libssh2_hostkey_method_ssh_dss_sig_verify(LIBSSH2_SESSION * session,
     return _libssh2_dsa_sha1_verify(dsactx, sig, m, m_len);
 }
 
-/* }}} */
-
-/* {{{ libssh2_hostkey_method_ssh_dss_signv
+/*
+ * hostkey_method_ssh_dss_signv
+ *
  * Construct a signature from an array of vectors
  */
 static int
-libssh2_hostkey_method_ssh_dss_signv(LIBSSH2_SESSION * session,
-                                     unsigned char **signature,
-                                     unsigned long *signature_len,
-                                     unsigned long veccount,
-                                     const struct iovec datavec[],
-                                     void **abstract)
+hostkey_method_ssh_dss_signv(LIBSSH2_SESSION * session,
+                             unsigned char **signature,
+                             unsigned long *signature_len,
+                             unsigned long veccount,
+                             const struct iovec datavec[],
+                             void **abstract)
 {
     libssh2_dsa_ctx *dsactx = (libssh2_dsa_ctx *) (*abstract);
     unsigned char hash[SHA_DIGEST_LENGTH];
@@ -381,13 +383,13 @@ libssh2_hostkey_method_ssh_dss_signv(LIBSSH2_SESSION * session,
     return 0;
 }
 
-/* }}} */
-
-/* {{{ libssh2_hostkey_method_ssh_dss_dtor
+/*
+ * libssh2_hostkey_method_ssh_dss_dtor
+ *
  * Shutdown the hostkey method
  */
 static int
-libssh2_hostkey_method_ssh_dss_dtor(LIBSSH2_SESSION * session, void **abstract)
+hostkey_method_ssh_dss_dtor(LIBSSH2_SESSION * session, void **abstract)
 {
     libssh2_dsa_ctx *dsactx = (libssh2_dsa_ctx *) (*abstract);
     (void) session;
@@ -399,26 +401,24 @@ libssh2_hostkey_method_ssh_dss_dtor(LIBSSH2_SESSION * session, void **abstract)
     return 0;
 }
 
-/* }}} */
-
-static const LIBSSH2_HOSTKEY_METHOD libssh2_hostkey_method_ssh_dss = {
+static const LIBSSH2_HOSTKEY_METHOD hostkey_method_ssh_dss = {
     "ssh-dss",
     MD5_DIGEST_LENGTH,
-    libssh2_hostkey_method_ssh_dss_init,
-    libssh2_hostkey_method_ssh_dss_initPEM,
-    libssh2_hostkey_method_ssh_dss_sig_verify,
-    libssh2_hostkey_method_ssh_dss_signv,
+    hostkey_method_ssh_dss_init,
+    hostkey_method_ssh_dss_initPEM,
+    hostkey_method_ssh_dss_sig_verify,
+    hostkey_method_ssh_dss_signv,
     NULL,                       /* encrypt */
-    libssh2_hostkey_method_ssh_dss_dtor,
+    hostkey_method_ssh_dss_dtor,
 };
 #endif /* LIBSSH2_DSA */
 
-static const LIBSSH2_HOSTKEY_METHOD *_libssh2_hostkey_methods[] = {
+static const LIBSSH2_HOSTKEY_METHOD *hostkey_methods[] = {
 #if LIBSSH2_RSA
-    &libssh2_hostkey_method_ssh_rsa,
+    &hostkey_method_ssh_rsa,
 #endif /* LIBSSH2_RSA */
 #if LIBSSH2_DSA
-    &libssh2_hostkey_method_ssh_dss,
+    &hostkey_method_ssh_dss,
 #endif /* LIBSSH2_DSA */
     NULL
 };
@@ -426,10 +426,12 @@ static const LIBSSH2_HOSTKEY_METHOD *_libssh2_hostkey_methods[] = {
 const LIBSSH2_HOSTKEY_METHOD **
 libssh2_hostkey_methods(void)
 {
-    return _libssh2_hostkey_methods;
+    return hostkey_methods;
 }
 
-/* {{{ libssh2_hostkey_hash
+/*
+ * libssh2_hostkey_hash
+ *
  * Returns hash signature
  * Returned buffer should NOT be freed
  * Length of buffer is determined by hash type
@@ -451,5 +453,3 @@ libssh2_hostkey_hash(LIBSSH2_SESSION * session, int hash_type)
         return NULL;
     }
 }
-
-/* }}} */
