@@ -1,4 +1,5 @@
-/* Copyright (c) 2004-2007, Sara Golemon <sarag@libssh2.org>
+/* Copyright (c) 2004-2008, Sara Golemon <sarag@libssh2.org>
+ * Copyright (c) 2009 by Daniel Stenberg
  * All rights reserved.
  *
  * Redistribution and use in source and binary forms,
@@ -41,6 +42,17 @@
 #define LIBSSH2_LIBRARY
 #include "libssh2_config.h"
 
+#ifdef HAVE_WINDOWS_H
+#include <windows.h>
+#endif
+
+#ifdef HAVE_WS2TCPIP_H
+#include <ws2tcpip.h>
+#endif
+
+#include <stdio.h>
+#include <time.h>
+
 /* The following CPP block should really only be in session.c and
    packet.c.  However, AIX have #define's for 'events' and 'revents'
    and we are using those names in libssh2.h, so we need to include
@@ -51,12 +63,10 @@
    http://www.mail-archive.com/libssh2-devel%40lists.sourceforge.net/msg00003.html
    http://www.mail-archive.com/libssh2-devel%40lists.sourceforge.net/msg00224.html
 */
-#include <stdio.h>
-
 #ifdef HAVE_POLL
 # include <sys/poll.h>
 #else
-# ifdef HAVE_SELECT
+# if defined(HAVE_SELECT) && !defined(WIN32)
 # ifdef HAVE_SYS_SELECT_H
 # include <sys/select.h>
 # else
@@ -70,6 +80,35 @@
 #include "libssh2_publickey.h"
 #include "libssh2_sftp.h"
 
+#ifndef FALSE
+#define FALSE 0
+#endif
+#ifndef TRUE
+#define TRUE 1
+#endif
+
+/* Provide iovec / writev on WIN32 platform. */
+#ifdef WIN32
+
+/* same as WSABUF */
+struct iovec {
+    u_long iov_len;
+    char *iov_base;
+};
+
+#define inline __inline
+
+static inline int writev(int sock, struct iovec *iov, int nvecs)
+{
+    DWORD ret;
+    if (WSASend(sock, (LPWSABUF)iov, nvecs, &ret, 0, NULL, NULL) == 0) {
+        return ret;
+    }
+    return -1;
+}
+
+#endif /* WIN32 */
+
 /* Needed for struct iovec on some platforms */
 #ifdef HAVE_SYS_UIO_H
 #include <sys/uio.h>
@@ -91,6 +130,19 @@
 #include "openssl.h"
 #endif
 
+#ifdef HAVE_WINSOCK2_H
+
+#include <winsock2.h>
+#include <mswsock.h>
+#include <ws2tcpip.h>
+
+#ifdef _MSC_VER
+/* "inline" keyword is valid only with C++ engine! */
+#define inline __inline
+#endif
+
+#endif
+
 /* RFC4253 section 6.1 Maximum Packet Length says:
  *
  * "All implementations MUST be able to process packets with
@@ -100,13 +152,20 @@
  */
 #define MAX_SSH_PACKET_LEN 35000
 
-#define LIBSSH2_ALLOC(session, count)                               session->alloc((count), &(session)->abstract)
-#define LIBSSH2_REALLOC(session, ptr, count)                        ((ptr) ? session->realloc((ptr), (count), &(session)->abstract) : session->alloc((count), &(session)->abstract))
-#define LIBSSH2_FREE(session, ptr)                                  session->free((ptr), &(session)->abstract)
-
-#define LIBSSH2_IGNORE(session, data, datalen)                      session->ssh_msg_ignore((session), (data), (datalen), &(session)->abstract)
-#define LIBSSH2_DEBUG(session, always_display, message, message_len, language, language_len)    \
-                session->ssh_msg_disconnect((session), (always_display), (message), (message_len), (language), (language_len), &(session)->abstract)
+#define LIBSSH2_ALLOC(session, count) \
+  session->alloc((count), &(session)->abstract)
+#define LIBSSH2_REALLOC(session, ptr, count) \
+ ((ptr) ? session->realloc((ptr), (count), &(session)->abstract) : \
+ session->alloc((count), &(session)->abstract))
+#define LIBSSH2_FREE(session, ptr) \
+ session->free((ptr), &(session)->abstract)
+#define LIBSSH2_IGNORE(session, data, datalen) \
+ session->ssh_msg_ignore((session), (data), (datalen), &(session)->abstract)
+#define LIBSSH2_DEBUG(session, always_display, message, message_len, \
+                      language, language_len)    \
+    session->ssh_msg_disconnect((session), (always_display), (message), \
+                                (message_len), (language), (language_len), \
+                                &(session)->abstract)
 #define LIBSSH2_DISCONNECT(session, reason, message, message_len, language, language_len)   \
                 session->ssh_msg_disconnect((session), (reason), (message), (message_len), (language), (language_len), &(session)->abstract)
 
@@ -336,11 +395,8 @@ struct _LIBSSH2_CHANNEL
     libssh2_nonblocking_states read_state;
     LIBSSH2_PACKET *read_packet;
     LIBSSH2_PACKET *read_next;
-    int read_block;
-    int read_bytes_read;
+
     uint32_t read_local_id;
-    int read_want;
-    int read_unlink_packet;
 
     /* State variables used in libssh2_channel_write_ex() */
     libssh2_nonblocking_states write_state;
@@ -415,7 +471,7 @@ typedef struct _libssh2_endpoint_data
     char *lang_prefs;
 } libssh2_endpoint_data;
 
-#define PACKETBUFSIZE 4096
+#define PACKETBUFSIZE (1024*16)
 
 struct transportpacket
 {
@@ -481,12 +537,19 @@ struct _LIBSSH2_PUBLICKEY
     unsigned long listFetch_data_len;
 };
 
+#define SFTP_HANDLE_MAXLEN 256 /* according to spec! */
+
 struct _LIBSSH2_SFTP_HANDLE
 {
     LIBSSH2_SFTP *sftp;
     LIBSSH2_SFTP_HANDLE *prev, *next;
 
-    char *handle;
+    /* This is a pre-allocated buffer used for sending SFTP requests as the
+       whole thing might not get sent in one go. This buffer is used for read,
+       write, close and MUST thus be big enough to suit all these. */
+    unsigned char request_packet[SFTP_HANDLE_MAXLEN + 25];
+
+    char handle[SFTP_HANDLE_MAXLEN];
     int handle_len;
 
     char handle_type;
@@ -621,6 +684,9 @@ struct _LIBSSH2_SESSION
     unsigned char *session_id;
     unsigned long session_id_len;
 
+    /* this is set to TRUE if a blocking API behavior is requested */
+    int api_block_mode;
+
     /* Server's public key */
     const LIBSSH2_HOSTKEY_METHOD *hostkey;
     void *server_hostkey_abstract;
@@ -641,7 +707,8 @@ struct _LIBSSH2_SESSION
     /* (local as source of data -- packet_write ) */
     libssh2_endpoint_data local;
 
-    /* Inbound Data buffer -- Sometimes the packet that comes in isn't the packet we're ready for */
+    /* Inbound Data buffer -- Sometimes the packet that comes in isn't the
+       packet we're ready for */
     LIBSSH2_PACKET_BRIGADE packets;
 
     /* Active connection channels */
@@ -652,8 +719,10 @@ struct _LIBSSH2_SESSION
 
     /* Actual I/O socket */
     int socket_fd;
-    int socket_block;
     int socket_state;
+    int socket_block_directions;
+    int socket_prev_blockstate; /* stores the state of the socket blockiness
+                                   when libssh2_session_startup() is called */
 
     /* Error tracking */
     char *err_msg;
@@ -802,7 +871,8 @@ struct _LIBSSH2_SESSION
     libssh2_nonblocking_states sftpInit_state;
     LIBSSH2_SFTP *sftpInit_sftp;
     LIBSSH2_CHANNEL *sftpInit_channel;
-    unsigned char sftpInit_buffer[9];   /* sftp_header(5){excludes request_id} + version_id(4) */
+    unsigned char sftpInit_buffer[9];   /* sftp_header(5){excludes request_id}
+                                           + version_id(4) */
 
     /* State variables used in libssh2_scp_recv() */
     libssh2_nonblocking_states scpRecv_state;
@@ -811,7 +881,14 @@ struct _LIBSSH2_SESSION
     unsigned char scpRecv_response[LIBSSH2_SCP_RESPONSE_BUFLEN];
     unsigned long scpRecv_response_len;
     long scpRecv_mode;
+#if defined(HAVE_LONGLONG) && defined(strtoll)
+    /* we have the type and we can parse such numbers */
+    long long scpRecv_size;
+#define scpsize_strtol strtoll
+#else
     long scpRecv_size;
+#define scpsize_strtol strtol
+#endif
     long scpRecv_mtime;
     long scpRecv_atime;
     char *scpRecv_err_msg;
@@ -833,6 +910,7 @@ struct _LIBSSH2_SESSION
 #define LIBSSH2_STATE_EXCHANGING_KEYS   0x00000001
 #define LIBSSH2_STATE_NEWKEYS           0x00000002
 #define LIBSSH2_STATE_AUTHENTICATED     0x00000004
+#define LIBSSH2_STATE_KEX_ACTIVE        0x00000008
 
 /* session.flag helpers */
 #ifdef MSG_NOSIGNAL
@@ -1054,16 +1132,24 @@ _libssh2_debug(LIBSSH2_SESSION * session, int context, const char *format, ...)
 #define SSH_MSG_CHANNEL_SUCCESS                     99
 #define SSH_MSG_CHANNEL_FAILURE                     100
 
-void libssh2_session_shutdown(LIBSSH2_SESSION * session);
+void _libssh2_session_shutdown(LIBSSH2_SESSION * session);
 
-unsigned long libssh2_ntohu32(const unsigned char *buf);
-libssh2_uint64_t libssh2_ntohu64(const unsigned char *buf);
-void libssh2_htonu32(unsigned char *buf, unsigned long val);
-void libssh2_htonu64(unsigned char *buf, libssh2_uint64_t val);
+unsigned int _libssh2_ntohu32(const unsigned char *buf);
+libssh2_uint64_t _libssh2_ntohu64(const unsigned char *buf);
+void _libssh2_htonu32(unsigned char *buf, unsigned int val);
+
+#ifdef WIN32
+ssize_t _libssh2_recv(int socket, void *buffer, size_t length, int flags);
+ssize_t _libssh2_send(int socket, const void *buffer, size_t length, int flags);
+#else
+#define _libssh2_recv(a,b,c,d) recv(a,b,c,d)
+#define _libssh2_send(a,b,c,d) send(a,b,c,d)
+#endif
 
 #define LIBSSH2_READ_TIMEOUT 60 /* generic timeout in seconds used when
                                    waiting for more data to arrive */
-int libssh2_waitsocket(LIBSSH2_SESSION * session, long seconds);
+
+int _libssh2_wait_socket(LIBSSH2_SESSION *session);
 
 
 /* CAUTION: some of these error codes are returned in the public API and is
@@ -1079,55 +1165,53 @@ int libssh2_waitsocket(LIBSSH2_SESSION * session, long seconds);
 #define PACKET_FAIL     -1
 #define PACKET_NONE      0
 
-libssh2pack_t libssh2_packet_read(LIBSSH2_SESSION * session);
+libssh2pack_t _libssh2_packet_read(LIBSSH2_SESSION * session);
 
-int libssh2_packet_ask_ex(LIBSSH2_SESSION * session, unsigned char packet_type,
-                          unsigned char **data, unsigned long *data_len,
-                          unsigned long match_ofs,
-                          const unsigned char *match_buf,
-                          unsigned long match_len, int poll_socket);
+int _libssh2_packet_ask(LIBSSH2_SESSION * session, unsigned char packet_type,
+                        unsigned char **data, unsigned long *data_len,
+                        unsigned long match_ofs,
+                        const unsigned char *match_buf,
+                        unsigned long match_len);
 
-int libssh2_packet_askv_ex(LIBSSH2_SESSION * session,
-                           const unsigned char *packet_types,
-                           unsigned char **data, unsigned long *data_len,
-                           unsigned long match_ofs,
-                           const unsigned char *match_buf,
-                           unsigned long match_len, int poll_socket);
-int libssh2_packet_require_ex(LIBSSH2_SESSION * session,
-                              unsigned char packet_type, unsigned char **data,
-                              unsigned long *data_len, unsigned long match_ofs,
-                              const unsigned char *match_buf,
-                              unsigned long match_len,
-                              packet_require_state_t * state);
-int libssh2_packet_requirev_ex(LIBSSH2_SESSION * session,
-                               const unsigned char *packet_types,
-                               unsigned char **data, unsigned long *data_len,
-                               unsigned long match_ofs,
-                               const unsigned char *match_buf,
-                               unsigned long match_len,
-                               packet_requirev_state_t * state);
-int libssh2_packet_burn(LIBSSH2_SESSION * session,
-                        libssh2_nonblocking_states * state);
-int libssh2_packet_write(LIBSSH2_SESSION * session, unsigned char *data,
-                         unsigned long data_len);
-int libssh2_packet_add(LIBSSH2_SESSION * session, unsigned char *data,
-                       size_t datalen, int macstate);
+int _libssh2_packet_askv(LIBSSH2_SESSION * session,
+                         const unsigned char *packet_types,
+                         unsigned char **data, unsigned long *data_len,
+                         unsigned long match_ofs,
+                         const unsigned char *match_buf,
+                         unsigned long match_len);
+int _libssh2_packet_require(LIBSSH2_SESSION * session,
+                            unsigned char packet_type, unsigned char **data,
+                            unsigned long *data_len, unsigned long match_ofs,
+                            const unsigned char *match_buf,
+                            unsigned long match_len,
+                            packet_require_state_t * state);
+int _libssh2_packet_requirev(LIBSSH2_SESSION * session,
+                             const unsigned char *packet_types,
+                             unsigned char **data, unsigned long *data_len,
+                             unsigned long match_ofs,
+                             const unsigned char *match_buf,
+                             unsigned long match_len,
+                             packet_requirev_state_t * state);
+int _libssh2_packet_burn(LIBSSH2_SESSION * session,
+                         libssh2_nonblocking_states * state);
+int _libssh2_packet_write(LIBSSH2_SESSION * session, unsigned char *data,
+                          unsigned long data_len);
+int _libssh2_packet_add(LIBSSH2_SESSION * session, unsigned char *data,
+                        size_t datalen, int macstate);
 int libssh2_kex_exchange(LIBSSH2_SESSION * session, int reexchange,
                          key_exchange_state_t * state);
-unsigned long libssh2_channel_nextid(LIBSSH2_SESSION * session);
-LIBSSH2_CHANNEL *libssh2_channel_locate(LIBSSH2_SESSION * session,
-                                        unsigned long channel_id);
-unsigned long libssh2_channel_packet_data_len(LIBSSH2_CHANNEL * channel,
-                                              int stream_id);
+unsigned long _libssh2_channel_nextid(LIBSSH2_SESSION * session);
+LIBSSH2_CHANNEL *_libssh2_channel_locate(LIBSSH2_SESSION * session,
+                                         unsigned long channel_id);
+unsigned long _libssh2_channel_packet_data_len(LIBSSH2_CHANNEL * channel,
+                                               int stream_id);
 
 /* this is the lib-internal set blocking function */
 int _libssh2_session_set_blocking(LIBSSH2_SESSION * session, int blocking);
 
-/* Let crypt.c/hostkey.c/comp.c/mac.c expose their method structs */
+/* Let crypt.c/hostkey.c expose their method structs */
 const LIBSSH2_CRYPT_METHOD **libssh2_crypt_methods(void);
 const LIBSSH2_HOSTKEY_METHOD **libssh2_hostkey_methods(void);
-const LIBSSH2_COMP_METHOD **libssh2_comp_methods(void);
-const LIBSSH2_MAC_METHOD **libssh2_mac_methods(void);
 
 /* Language API doesn't exist yet.  Just act like we've agreed on a language */
 #define libssh2_kex_agree_lang(session, endpoint, str, str_len) 0
@@ -1136,9 +1220,54 @@ const LIBSSH2_MAC_METHOD **libssh2_mac_methods(void);
 int _libssh2_pem_parse(LIBSSH2_SESSION * session,
                        const char *headerbegin,
                        const char *headerend,
-                       FILE * fp, char **data, unsigned int *datalen);
+                       FILE * fp, unsigned char **data, unsigned int *datalen);
 int _libssh2_pem_decode_sequence(unsigned char **data, unsigned int *datalen);
 int _libssh2_pem_decode_integer(unsigned char **data, unsigned int *datalen,
                                 unsigned char **i, unsigned int *ilen);
 
+
+/* Conveniance-macros to allow code like this;
+
+   int rc = BLOCK_ADJUST(rc, session, session_startup(session, sock) );
+
+   int rc = BLOCK_ADJUST_ERRNO(ptr, session, session_startup(session, sock) );
+
+   The point of course being to make sure that while in non-blocking mode
+   these always return no matter what the return code is, but in blocking mode
+   it blocks if EAGAIN is the reason for the return from the underlying
+   function.
+
+*/
+#define BLOCK_ADJUST(rc,sess,x) \
+    do { \
+       rc = x; \
+       /* the order of the check below is important to properly deal with the
+          case when the 'sess' is freed */ \
+       if((rc != LIBSSH2_ERROR_EAGAIN) || !sess->api_block_mode)  \
+           break; \
+       rc = _libssh2_wait_socket(sess); \
+       if(rc) \
+           break; \
+    } while(1)
+
+/*
+ * For functions that returns a pointer, we need to check if the API is
+ * non-blocking and return immediately. If the pointer is non-NULL we return
+ * immediately. If the API is blocking and we get a NULL we check the errno
+ * and *only* if that is EAGAIN we loop and wait for socket action.
+ */
+#define BLOCK_ADJUST_ERRNO(ptr,sess,x)          \
+    do { \
+       int rc; \
+       ptr = x; \
+       if(!sess->api_block_mode || \
+          (ptr != NULL) || \
+          (libssh2_session_last_errno(sess) != LIBSSH2_ERROR_EAGAIN) ) \
+           break;                                                  \
+       rc = _libssh2_wait_socket(sess); \
+       if(rc) \
+           break; \
+    } while(1)
+
+
 #endif /* LIBSSH2_H */
