@@ -1,4 +1,5 @@
 /* Copyright (C) 2007 The Written Word, Inc.  All rights reserved.
+ * Copyright (C) 2009 by Daniel Stenberg
  * Author: Daniel Stenberg <daniel@haxx.se>
  *
  * Redistribution and use in source and binary forms,
@@ -43,8 +44,10 @@
 
 #include <assert.h>
 
-#define MAX_BLOCKSIZE 32        /* MUST fit biggest crypto block size we use/get */
-#define MAX_MACSIZE 20          /* MUST fit biggest MAC length we support */
+#include "transport.h"
+
+#define MAX_BLOCKSIZE 32     /* MUST fit biggest crypto block size we use/get */
+#define MAX_MACSIZE 20      /* MUST fit biggest MAC length we support */
 
 #ifdef LIBSSH2DEBUG
 #define UNPRINTABLE_CHAR '.'
@@ -54,7 +57,7 @@ debugdump(LIBSSH2_SESSION * session,
 {
     size_t i;
     size_t c;
-    FILE *stream = stdout;
+    FILE *stream = stderr;
     unsigned int width = 0x10;
 
     if (!(session->showmask & (1 << LIBSSH2_DBG_TRANS))) {
@@ -169,7 +172,8 @@ fullpacket(LIBSSH2_SESSION * session, int encrypted /* 1 or 0 */ )
         session->fullpacket_payload_len -= p->padding_length;
 
         /* Check for and deal with decompression */
-        if (session->remote.comp && strcmp(session->remote.comp->name, "none")) {
+        if (session->remote.comp &&
+            strcmp(session->remote.comp->name, "none")) {
             unsigned char *data;
             unsigned long data_len;
             int free_payload = 1;
@@ -207,8 +211,7 @@ fullpacket(LIBSSH2_SESSION * session, int encrypted /* 1 or 0 */ )
                     p->payload = LIBSSH2_ALLOC(session, data_len);
                     if (!p->payload) {
                         libssh2_error(session, LIBSSH2_ERROR_ALLOC, (char *)
-                                      "Unable to allocate memory for copy of uncompressed data",
-                                      0);
+                                      "Unable to allocate memory", 0);
                         return PACKET_ENOMEM;
                     }
                     memcpy(p->payload, data, data_len);
@@ -219,16 +222,16 @@ fullpacket(LIBSSH2_SESSION * session, int encrypted /* 1 or 0 */ )
 
         session->fullpacket_packet_type = p->payload[0];
 
-        debugdump(session, "libssh2_packet_read() plain",
+        debugdump(session, "libssh2_transport_read() plain",
                   p->payload, session->fullpacket_payload_len);
 
         session->fullpacket_state = libssh2_NB_state_created;
     }
 
     if (session->fullpacket_state == libssh2_NB_state_created) {
-        rc = libssh2_packet_add(session, p->payload,
-                                session->fullpacket_payload_len,
-                                session->fullpacket_macstate);
+        rc = _libssh2_packet_add(session, p->payload,
+                                 session->fullpacket_payload_len,
+                                 session->fullpacket_macstate);
         if (rc == PACKET_EAGAIN) {
             return PACKET_EAGAIN;
         } else if (rc < 0) {
@@ -242,10 +245,11 @@ fullpacket(LIBSSH2_SESSION * session, int encrypted /* 1 or 0 */ )
 }
 
 
-/* {{{ libssh2_packet_read
- * Collect a packet into the input brigade
- * block only controls whether or not to wait for a packet to start,
- * Once a packet starts, libssh2 will block until it is complete
+/*
+ * _libssh2_transport_read
+ *
+ * Collect a packet into the input brigade block only controls whether or not
+ * to wait for a packet to start.
  *
  * Returns packet type added to input brigade (PACKET_NONE if nothing added),
  * or PACKET_FAIL on failure and PACKET_EAGAIN if it couldn't process a full
@@ -257,7 +261,7 @@ fullpacket(LIBSSH2_SESSION * session, int encrypted /* 1 or 0 */ )
  * "The Secure Shell (SSH) Transport Layer Protocol"
  */
 libssh2pack_t
-libssh2_packet_read(LIBSSH2_SESSION * session)
+_libssh2_transport_read(LIBSSH2_SESSION * session)
 {
     libssh2pack_t rc;
     struct transportpacket *p = &session->packet;
@@ -269,6 +273,40 @@ libssh2_packet_read(LIBSSH2_SESSION * session)
     int blocksize;
     int encrypted = 1;
 
+    int status;
+
+    /*
+     * All channels, systems, subsystems, etc eventually make it down here
+     * when looking for more incoming data. If a key exchange is going on
+     * (LIBSSH2_STATE_EXCHANGING_KEYS bit is set) then the remote end will
+     * ONLY send key exchange related traffic. In non-blocking mode, there is
+     * a chance to break out of the kex_exchange function with an EAGAIN
+     * status, and never come back to it. If LIBSSH2_STATE_EXCHANGING_KEYS is
+     * active, then we must redirect to the key exchange. However, if
+     * kex_exchange is active (as in it is the one that calls this execution
+     * of packet_read, then don't redirect, as that would be an infinite loop!
+     */
+
+    if (session->state & LIBSSH2_STATE_EXCHANGING_KEYS &&
+        !(session->state & LIBSSH2_STATE_KEX_ACTIVE)) {
+
+        /* Whoever wants a packet won't get anything until the key re-exchange
+         * is done!
+         */
+        _libssh2_debug(session, LIBSSH2_DBG_TRANS, "Redirecting into the"
+            " key re-exchange");
+        status = libssh2_kex_exchange(session, 1, &session->startup_key_state);
+        if (status == PACKET_EAGAIN) {
+            libssh2_error(session, LIBSSH2_ERROR_EAGAIN,
+                "Would block exchanging encryption keys", 0);
+            return PACKET_EAGAIN;
+      } else if (status) {
+          libssh2_error(session, LIBSSH2_ERROR_KEX_FAILURE,
+                      "Unable to exchange encryption keys",0);
+          return LIBSSH2_ERROR_KEX_FAILURE;
+      }
+    }
+
     /*
      * =============================== NOTE ===============================
      * I know this is very ugly and not a really good use of "goto", but
@@ -277,7 +315,7 @@ libssh2_packet_read(LIBSSH2_SESSION * session)
     if (session->readPack_state == libssh2_NB_state_jump1) {
         session->readPack_state = libssh2_NB_state_idle;
         encrypted = session->readPack_encrypted;
-        goto libssh2_packet_read_point1;
+        goto libssh2_transport_read_point1;
     }
 
     do {
@@ -324,38 +362,20 @@ libssh2_packet_read(LIBSSH2_SESSION * session)
 
             /* now read a big chunk from the network into the temp buffer */
             nread =
-                recv(session->socket_fd, &p->buf[remainbuf],
+                _libssh2_recv(session->socket_fd, &p->buf[remainbuf],
                      PACKETBUFSIZE - remainbuf,
                      LIBSSH2_SOCKET_RECV_FLAGS(session));
             if (nread <= 0) {
                 /* check if this is due to EAGAIN and return the special
                    return code if so, error out normally otherwise */
-#ifdef WIN32
-                switch (WSAGetLastError()) {
-                case WSAEWOULDBLOCK:
-                    errno = EAGAIN;
-                    break;
-
-                case WSAENOTSOCK:
-                    errno = EBADF;
-                    break;
-
-                case WSAENOTCONN:
-                case WSAECONNABORTED:
-                    errno = WSAENOTCONN;
-                    break;
-
-                case WSAEINTR:
-                    errno = EINTR;
-                    break;
-                }
-#endif /* WIN32 */
                 if ((nread < 0) && (errno == EAGAIN)) {
+                    session->socket_block_directions =
+                        LIBSSH2_SESSION_BLOCK_INBOUND;
                     return PACKET_EAGAIN;
                 }
                 return PACKET_FAIL;
             }
-            debugdump(session, "libssh2_packet_read() raw",
+            debugdump(session, "libssh2_transport_read() raw",
                       &p->buf[remainbuf], nread);
             /* advance write pointer */
             p->writeidx += nread;
@@ -400,7 +420,7 @@ libssh2_packet_read(LIBSSH2_SESSION * session)
             /* we now have the initial blocksize bytes decrypted,
              * and we can extract packet and padding length from it
              */
-            p->packet_length = libssh2_ntohu32(block);
+            p->packet_length = _libssh2_ntohu32(block);
             p->padding_length = block[4];
 
             /* total_num is the number of bytes following the initial
@@ -524,11 +544,24 @@ libssh2_packet_read(LIBSSH2_SESSION * session)
 
         if (!remainpack) {
             /* we have a full packet */
-          libssh2_packet_read_point1:
+          libssh2_transport_read_point1:
             rc = fullpacket(session, encrypted);
             if (rc == PACKET_EAGAIN) {
-                session->readPack_encrypted = encrypted;
-                session->readPack_state = libssh2_NB_state_jump1;
+
+                if (session->packAdd_state != libssh2_NB_state_idle)
+                {
+                    /* fullpacket only returns PACKET_EAGAIN if
+                     * libssh2_packet_add returns PACKET_EAGAIN. If that
+                     * returns PACKET_EAGAIN but the packAdd_state is idle,
+                     * then the packet has been added to the brigade, but some
+                     * immediate action that was taken based on the packet
+                     * type (such as key re-exchange) is not yet complete.
+                     * Clear the way for a new packet to be read in.
+                     */
+                    session->readPack_encrypted = encrypted;
+                    session->readPack_state = libssh2_NB_state_jump1;
+                }
+
                 return PACKET_EAGAIN;
             }
 
@@ -541,10 +574,6 @@ libssh2_packet_read(LIBSSH2_SESSION * session)
     return PACKET_FAIL;         /* we never reach this point */
 }
 
-/* }}} */
-
-#ifndef OLDSEND
-
 static libssh2pack_t
 send_existing(LIBSSH2_SESSION * session, unsigned char *data,
               unsigned long data_len, ssize_t * ret)
@@ -573,7 +602,7 @@ send_existing(LIBSSH2_SESSION * session, unsigned char *data,
     /* number of bytes left to send */
     length = p->ototal_num - p->osent;
 
-    rc = send(session->socket_fd, &p->outbuf[p->osent], length,
+    rc = _libssh2_send(session->socket_fd, &p->outbuf[p->osent], length,
               LIBSSH2_SOCKET_SEND_FLAGS(session));
 
     if (rc == length) {
@@ -587,17 +616,20 @@ send_existing(LIBSSH2_SESSION * session, unsigned char *data,
             /* send failure! */
             return PACKET_FAIL;
         }
+        session->socket_block_directions = LIBSSH2_SESSION_BLOCK_OUTBOUND;
         return PACKET_EAGAIN;
     }
 
-    debugdump(session, "libssh2_packet_write send()", &p->outbuf[p->osent],
+    debugdump(session, "libssh2_transport_write send()", &p->outbuf[p->osent],
               length);
     p->osent += length;         /* we sent away this much data */
 
     return PACKET_NONE;
 }
 
-/* {{{ libssh2_packet_write
+/*
+ * libssh2_transport_write
+ *
  * Send a packet, encrypting it and adding a MAC code if necessary
  * Returns 0 on success, non-zero on failure.
  *
@@ -605,10 +637,14 @@ send_existing(LIBSSH2_SESSION * session, unsigned char *data,
  * call this function again as soon as it is likely that more data can be
  * sent, and this function should then be called with the same argument set
  * (same data pointer and same data_len) until zero or failure is returned.
+ *
+ * NOTE: this function does not verify that 'data_len' is less than ~35000
+ * which is what all implementations should support at least as packet size.
+ * (RFC4253 section 6.1)
  */
 int
-libssh2_packet_write(LIBSSH2_SESSION * session, unsigned char *data,
-                     unsigned long data_len)
+_libssh2_transport_write(LIBSSH2_SESSION * session, unsigned char *data,
+                         unsigned long data_len)
 {
     int blocksize =
         (session->state & LIBSSH2_STATE_NEWKEYS) ? session->local.crypt->
@@ -629,7 +665,7 @@ libssh2_packet_write(LIBSSH2_SESSION * session, unsigned char *data,
     unsigned char *orgdata = data;
     unsigned long orgdata_len = data_len;
 
-    debugdump(session, "libssh2_packet_write plain", data, data_len);
+    debugdump(session, "libssh2_transport_write plain", data, data_len);
 
     /* FIRST, check if we have a pending write to complete */
     rc = send_existing(session, data, data_len, &ret);
@@ -641,9 +677,10 @@ libssh2_packet_write(LIBSSH2_SESSION * session, unsigned char *data,
 
     /* check if we should compress */
     if (encrypted && strcmp(session->local.comp->name, "none")) {
-        if (session->local.comp->
-            comp(session, 1, &data, &data_len, LIBSSH2_PACKET_MAXCOMP,
-                 &free_data, data, data_len, &session->local.comp_abstract)) {
+        if (session->local.comp->comp(session, 1, &data, &data_len,
+                                      LIBSSH2_PACKET_MAXCOMP,
+                                      &free_data, data, data_len,
+                                      &session->local.comp_abstract)) {
             return PACKET_COMPRESS;     /* compression failure */
         }
     }
@@ -697,7 +734,7 @@ libssh2_packet_write(LIBSSH2_SESSION * session, unsigned char *data,
 
     /* store packet_length, which is the size of the whole packet except
        the MAC and the packet_length field itself */
-    libssh2_htonu32(p->outbuf, packet_length - 4);
+    _libssh2_htonu32(p->outbuf, packet_length - 4);
     /* store padding_length */
     p->outbuf[4] = padding_length;
     /* copy the payload data */
@@ -722,23 +759,24 @@ libssh2_packet_write(LIBSSH2_SESSION * session, unsigned char *data,
            The MAC field is not encrypted. */
         for(i = 0; i < packet_length; i += session->local.crypt->blocksize) {
             unsigned char *ptr = &p->outbuf[i];
-            if (session->local.crypt->
-                crypt(session, ptr, &session->local.crypt_abstract))
+            if (session->local.crypt->crypt(session, ptr,
+                                            &session->local.crypt_abstract))
                 return PACKET_FAIL;     /* encryption failure */
         }
     }
 
     session->local.seqno++;
 
-    ret = send(session->socket_fd, p->outbuf, total_length,
+    ret = _libssh2_send(session->socket_fd, p->outbuf, total_length,
                LIBSSH2_SOCKET_SEND_FLAGS(session));
 
     if (ret != -1) {
-        debugdump(session, "libssh2_packet_write send()", p->outbuf, ret);
+        debugdump(session, "libssh2_transport_write send()", p->outbuf, ret);
     }
     if (ret != total_length) {
         if ((ret > 0) || ((ret == -1) && (errno == EAGAIN))) {
             /* the whole packet could not be sent, save the rest */
+            session->socket_block_directions = LIBSSH2_SESSION_BLOCK_OUTBOUND;
             p->odata = orgdata;
             p->olen = orgdata_len;
             p->osent = (ret == -1) ? 0 : ret;
@@ -757,5 +795,5 @@ libssh2_packet_write(LIBSSH2_SESSION * session, unsigned char *data,
     return PACKET_NONE;         /* all is good */
 }
 
-/* }}} */
-#endif
+
+
